/**
 * BeanPot Bean Container Project.
 * Copyright (C) 2009  Rubecula Software, LLC.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Module: Configurable.java
 * Created on Mar 10, 2009
 * @version $Revision: 1.1 $
 */

package com.rubecula.beanpot;

/**
 * An interface to allow beans to provide special handling before and after
 * configuration but of course always after instantiation.
 * 
 * @author Robin Hillyard
 * 
 */
public interface Configurable {

	/**
	 * Method to post-configure a bean after configuration proper (which
	 * includes dependency injection) but before the bean is run (if it is run).
	 * 
	 * @param data
	 *            some object which may or may not be used in
	 *            post-configuration.
	 * @throws BeanPotException
	 */
	public abstract void postConfigure(Object data) throws BeanPotException;

	/**
	 * Method to pre-configure a bean after construction but before
	 * configuration proper (which includes dependency injection).
	 * 
	 * @param data
	 *            some object which may or may not be used in pre-configuration.
	 * @throws BeanPotException
	 */
	public abstract void preConfigure(Object data) throws BeanPotException;

}
