/**
 * BeanPot Bean Container Project.
 * Copyright (C) 2009  Rubecula Software, LLC.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Module: ConsoleWriter.java
 * Created on Mar 11, 2009
 * @version $Revision: 1.1 $
 */

package com.rubecula.beanpot;

import java.io.OutputStream;
import java.io.PrintWriter;

/**
 * Convenience class to allow writing to the console. This wouldn't be necessary
 * if we could dynamically set the destination of a {@link PrintWriter}.
 * 
 * @author Robin Hillyard
 * 
 */
public class ConsoleWriter extends PrintWriter {

	/**
	 * Construct a ConsoleWriter to System.out and with auto-flush true.
	 */
	public ConsoleWriter() {
		super(System.out, true);
	}

	/**
	 * Construct a ConsoleWriter output stream out. Currently, auto-flush is off
	 * but see {@link PrintWriter#PrintWriter(OutputStream)} to be sure.
	 * 
	 * @param out
	 *            the output stream to use
	 */
	public ConsoleWriter(final OutputStream out) {
		super(out);
	}

	/**
	 * @param out
	 * @param autoFlush
	 */
	public ConsoleWriter(final OutputStream out, final boolean autoFlush) {
		super(out, autoFlush);
	}

}
