/**
 * BeanPot Bean Container Project.
 * Copyright (C) 2009  Rubecula Software, LLC.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Module: Kleenean.java
 * Created on Mar 29, 2009
 * @version $Revision: 1.1 $
 */

package com.rubecula.beanpot;

/**
 * Enumerated type providing three-valued logic named after S. C. Kleene.
 * 
 * @author Robin Hillyard
 * 
 */
public enum Kleenean {

	/**
	 * 
	 */
	True, /**
	 * 
	 */
	Maybe, /**
	 * 
	 */
	False;

	/**
	 * @param b
	 * @return <code>if b then True else False</code>
	 */
	public static Kleenean valueOf(final boolean b) {
		return b ? True : False;
	}

	/**
	 * @param k
	 * @return <code>if either this or k is False, then False; if either this or k is Maybe then Maybe; else True;</code>
	 */
	public Kleenean and(final Kleenean k) {
		if (this == False || k == False)
			return False;
		if (this == Maybe || k == Maybe)
			return Maybe;
		return True;
	}

	/**
	 * @return <code>if this is False, then True; if this is True then False; else Maybe;</code>
	 */
	public Kleenean not() {
		if (this == False)
			return True;
		if (this == True)
			return False;
		return Maybe;
	}

	/**
	 * @param k
	 * @return <code>if either this or k is True, then True; if either this or k is Maybe then Maybe; else False;</code>
	 */
	public Kleenean or(final Kleenean k) {
		if (this == True || k == True)
			return True;
		if (this == Maybe || k == Maybe)
			return Maybe;
		return False;
	}

}
