/**
 * BeanPot Bean Container Project.
 * Copyright (C) 2009  Rubecula Software, LLC.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Module: MBeanPot.java
 * Created on Mar 26, 2009
 * @version $Revision: 1.1 $
 */

package com.rubecula.beanpot;

/**
 * This interface defines the methods required to register and unregister beans
 * as MBeans.
 * 
 * The standard implementer, MBeanPotImpl is in the optional package:
 * com.rubecula.beanpot.jmx.
 * 
 * @author Robin Hillyard
 * 
 */
public interface MBeanPot {

	/**
	 * If bean is a valid MBean, then register it in the MBeanServer.
	 * 
	 * @param key
	 *            the (beanpot) name of the bean.
	 * @param bean
	 *            the bean to be registered.
	 * @throws BeanPotException
	 */
	public abstract void registerMBean(String key, Object bean) throws BeanPotException;

	/**
	 * If the bean has been registered with the MBeanServer, it will be
	 * unregistered.
	 * 
	 * @param key
	 *            the (beanpot) name of the bean.
	 */
	public void unregisterMBean(final String key);

}