/**
 * BeanPot Bean Container Project.
 * Copyright (C) 2009  Rubecula Software, LLC.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Module: ConsoleWriter.java
 * Created on Mar 11, 2009
 * @version $Revision: 1.1 $
 */

package com.rubecula.beanpot;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.io.Writer;

/**
 * Convenience class to allow writing to a StringWriter.
 * 
 * @author Robin Hillyard
 * 
 */
public class StringWriterWriter extends PrintWriter {

	/**
	 * Primary Constructor to construct a {@link StringWriterWriter} based on a
	 * newly constructed {@link StringWriter}.
	 */
	public StringWriterWriter() {
		this(new StringWriter());
	}

	/**
	 * Secondary Constructor to construct a {@link StringWriterWriter} based on
	 * the given <code>writer</code>.
	 * 
	 * @param writer
	 */
	public StringWriterWriter(final StringWriter writer) {
		super(writer);
		setWriter(writer);
	}

	/**
	 * @return the buffer for the current value of {@link #_writer}.
	 */
	public StringBuffer getBuffer() {
		return getWriter().getBuffer();
	}

	/**
	 * Flush, then convert the buffer to a string and save the result. Then
	 * clear the buffer.
	 * 
	 * @return the saved string.
	 */
	public String reset() {
		flush();
		final StringBuffer buffer = getBuffer();
		final String result = buffer.toString();
		buffer.delete(0, buffer.length());
		return result;
	}

	/**
	 * Reset the {@link StringWriter} which is used as the output for this
	 * {@link StringWriterWriter}. First, {@link Writer#flush()} is called on
	 * <code>this</code>. Then, {@link Writer#close()} is called on
	 * <code>this</code>. Finally, the StringWriter is replace with the given
	 * one.
	 * 
	 * @param writer
	 */
	public void setStringWriter(final StringWriter writer) {
		reset();
		close();
		this.out = writer;
		setWriter(writer);
	}

	/**
	 * @return the writer
	 */
	private StringWriter getWriter() {
		return this._writer;
	}

	/**
	 * @param writer
	 *            the writer to set
	 */
	private void setWriter(final StringWriter writer) {
		this._writer = writer;
	}

	private StringWriter _writer;
}
