/**
 * BeanPot Bean Container Project.
 * Copyright (C) 2009  Rubecula Software, LLC.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Module: MBeanPotImpl.java
 * Created on Mar 26, 2009
 * @version $Revision: 1.1 $
 */

package com.rubecula.beanpot.jmx;

import javax.management.JMException;
import javax.management.MBeanServer;
import javax.management.MalformedObjectNameException;
import javax.management.NotCompliantMBeanException;
import javax.management.ObjectName;

import com.rubecula.beanpot.BeanPot;
import com.rubecula.beanpot.BeanPotException;
import com.rubecula.beanpot.MBeanPot;

/**
 * Implementer of MBeanPot.
 * 
 * @author Robin Hillyard
 * 
 */
public class MBeanPotImpl implements MBeanPot {

	/**
	 * This is only for testing.
	 * 
	 * @param args
	 * @throws Exception
	 */
	public static void main(final String[] args) throws Exception {
		BeanPot.setValidate();
		BeanPot.setConfiguration(MBeanPotImpl.class, "MBeanPot.xml"); //$NON-NLS-1$
		BeanPot.setDebug(true);
		BeanPot.getInstance().run();
		// We don't get here until someone goes to the JConsole and sets running
		// to false for the MBeanPotImpl.
		System.out.println("MBeanPot finished"); //$NON-NLS-1$
	}

	/**
	 * @param mBeanServer
	 *            the MBeanServer where we register MBeans.
	 * @param mBeanPrefix
	 *            the first part of the object name which will be created for
	 *            any MBeans.
	 * 
	 */
	public MBeanPotImpl(final MBeanServer mBeanServer, final String mBeanPrefix) {
		_beanServer = mBeanServer;
		_mBeanPrefix = mBeanPrefix;
	}

	/**
	 * Create a new ObjectName based on
	 * 
	 * @see com.rubecula.beanpot.MBeanPot#registerMBean(java.lang.String,
	 *      java.lang.Object)
	 */
	public void registerMBean(final String key, final Object bean) throws BeanPotException {
		try {
			final ObjectName objectName = createObjectName(key);
			_beanServer.registerMBean(bean, objectName);
			// _beanServer.addNotificationListener(objectName, listener, filter,
			// handback);
			BeanPot.getBeanPotLogger().debug("MBean registered: " + objectName); //$NON-NLS-1$
		} catch (final NotCompliantMBeanException e) {
			throw new BeanPotException("Bean for key " + key + " is not an MBean"); //$NON-NLS-1$ //$NON-NLS-2$
		} catch (final JMException e) {
			throw new RuntimeException("MBeanPotImpl.registerMBean() JMX exception for key: " + key, e); //$NON-NLS-1$
		}
	}

	/**
	 * If the bean has been registered with JMX, it will be unregistered.
	 * 
	 * @param key
	 */
	public void unregisterMBean(final String key) {
		try {
			final ObjectName objectName = createObjectName(key);
			final boolean registered = _beanServer.isRegistered(objectName);
			if (registered)
				_beanServer.unregisterMBean(objectName);
		} catch (final JMException e) {
			throw new RuntimeException("MBeanPotImpl.unregisterMBean() JMX exception for key: " + key, e); //$NON-NLS-1$			
		}
	}

	private ObjectName createObjectName(final String key) throws MalformedObjectNameException {
		return new ObjectName((_mBeanPrefix + S_TYPE + key));
	}

	/**
	 * The center part of an MBean object name.
	 */
	private static final String S_TYPE = ":type="; //$NON-NLS-1$

	/**
	 * This is the MBean server.
	 */
	private final MBeanServer _beanServer;

	private final String _mBeanPrefix;

}
