/**
 * BeanPot Bean Container Project.
 * Copyright (C) 2009  Rubecula Software, LLC.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Module: MBeanTest.java
 * Created on Mar 26, 2009
 * @version $Revision: 1.1 $
 */

package com.rubecula.beanpot.jmx;

import com.rubecula.beanpot.BeanPotException;
import com.rubecula.beanpot.Closeable;
import com.rubecula.beanpot.Configurable;

/**
 * This class is referenced only by the MBeanPot.xml resource file, which in
 * turn is referenced only by the main() method of MBeanPotImpl, which is for
 * testing/documentation purposed only.
 * 
 * @author Robin Hillyard
 * 
 */
public class MBeanTest implements Configurable, Runnable, MBeanTestMBean, Closeable {

	/**
	 * @param id
	 */
	public MBeanTest(final Long id) {
		super();
		this._id = id;
		System.out.println("MBeanTest class instantiated with id: " + id); //$NON-NLS-1$
	}

	/**
	 * @return the id as a Long
	 * @see com.rubecula.beanpot.jmx.MBeanTestMBean#getId()
	 */
	public Long getId() {
		return this._id;
	}

	/**
	 * @return true if we are running.
	 * @see com.rubecula.beanpot.jmx.MBeanTestMBean#isRunning()
	 */
	public synchronized boolean isRunning() {
		return this.running;
	}

	/**
	 * 
	 * @see com.rubecula.beanpot.Configurable#postConfigure(java.lang.Object)
	 */
	public void postConfigure(final Object data) {
		System.out.println("post configure _bar"); //$NON-NLS-1$
	}

	/**
	 * 
	 * @see com.rubecula.beanpot.Configurable#preConfigure(java.lang.Object)
	 */
	public void preConfigure(final Object data) {
		System.out.println("pre configure _bar"); //$NON-NLS-1$
	}

	/**
	 * Run this once every second for 200 secs or until {@link #isRunning()}
	 * returns false.
	 * 
	 * @see java.lang.Runnable#run()
	 */
	public void run() {
		int count = 200;
		while (count-- > 0 && isRunning())
			try {
				Thread.sleep(1000);
			} catch (final InterruptedException e) {
				// ignore this exception
			}

	}

	/**
	 * @see com.rubecula.beanpot.jmx.MBeanTestMBean#setRunning(boolean)
	 */
	public synchronized void setRunning(final boolean running) {
		System.out.println("running set to " + running); //$NON-NLS-1$
		this.running = running;
	}

	private final Long _id;

	private boolean running = true;

	/**
	 * @see com.rubecula.beanpot.Closeable#close()
	 */
	public void close() throws BeanPotException {
		System.out.println("Closing bean " + getId()); //$NON-NLS-1$		
		if (isRunning())
			throw new BeanPotException("bean " + getId() + " still running"); //$NON-NLS-1$ //$NON-NLS-2$
	}

}