/**
 * BeanPot Bean Container Project.
 * Copyright (C) 2009  Rubecula Software, LLC.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Module: SerializeInputStream.java
 * Created on Jul 28, 2010
 * @version $Revision: 1.1 $
 */

package com.rubecula.beanpot.serialize;

import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;

/**
 * @author Robin Hillyard
 * 
 */
public class SerializeInputStream extends ObjectInputStream {

	/**
	 * @param in
	 * @throws IOException
	 */
	public SerializeInputStream(final InputStream in) throws IOException {
		super(in);
		this._in = in;
	}

	/**
	 * This is necessary because super.available() always yields 0. Since we are
	 * contracted to provide {@link #available()}, it seems we should return
	 * something reasonable. However, this may not be much more reliable.
	 * 
	 * @return the result of calling {@link InputStream#available()} on
	 *         {@link #_in}.
	 * @see java.io.ObjectInputStream#available()
	 */
	@Override
	public int available() throws IOException {
		return this._in.available();
	}

	/**
	 * Invokes {@link #close()} on the super object, and also on {@link #_in}.
	 * 
	 * @see java.io.ObjectInputStream#close()
	 */
	@Override
	public void close() throws IOException {
		super.close();
		// the following may be redundant
		this._in.close();
	}

	private final InputStream _in;

}
