/**
 * BeanPot Bean Container Project.
 * Copyright (C) 2009  Rubecula Software, LLC.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Module: SerializerFactory.java
 * Created on Jul 27, 2010
 * @version $Revision: 1.1 $
 */

package com.rubecula.beanpot.serialize;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.net.URL;

import com.rubecula.beanpot.Serializer;

/**
 * @author Robin Hillyard
 * 
 */
public final class SerializerFactory {

	/**
	 * @param file
	 * @param deleteAfter
	 *            XXX
	 * @return the newly constructed {@link Serializer_File}
	 * @throws IOException
	 * @throws FileNotFoundException
	 */
	public static Serializer createDeserializer(final File file, final boolean deleteAfter) throws FileNotFoundException,
			IOException {
		return makeSerializer(file, true, deleteAfter);
	}

	/**
	 * @param filename
	 * @param deleteAfter
	 *            XXX
	 * @return the newly constructed {@link Serializer_File}
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	public static Serializer createDeserializer(final String filename, final boolean deleteAfter) throws FileNotFoundException,
			IOException {
		return makeSerializer(filename, true, deleteAfter);
	}

	/**
	 * @param url
	 * @return the newly constructed {@link Serializer_Url}
	 * @throws IOException
	 */
	public static Serializer createDeserializer(final URL url) throws IOException {
		return makeSerializer(url, true);
	}

	/**
	 * @param file
	 * @return the newly constructed {@link Serializer_File}
	 * @throws IOException
	 * @throws FileNotFoundException
	 */
	public static Serializer createSerializer(final File file) throws FileNotFoundException, IOException {
		return makeSerializer(file, false, false);
	}

	/**
	 * @param filename
	 * @return the newly constructed {@link Serializer_File}
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	public static Serializer createSerializer(final String filename) throws FileNotFoundException, IOException {
		return makeSerializer(filename, false, false);
	}

	/**
	 * @param url
	 * @return the newly constructed {@link Serializer_Url}
	 * @throws IOException
	 */
	public static Serializer createSerializer(final URL url) throws IOException {
		return makeSerializer(url, false);
	}

	/**
	 * @param file
	 * @param restore
	 * @param deleteAfter
	 *            XXX
	 * @return a newly constructed {@link Serializer_File}.
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	private static Serializer makeSerializer(final File file, final boolean restore, final boolean deleteAfter)
			throws FileNotFoundException, IOException {
		return new Serializer_File(file, restore, deleteAfter);
	}

	/**
	 * @param filename
	 * @param restore
	 * @param deleteAfter
	 *            XXX
	 * @return the newly constructed {@link Serializer_File}
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	private static Serializer makeSerializer(final String filename, final boolean restore, final boolean deleteAfter)
			throws FileNotFoundException, IOException {
		return new Serializer_File(filename, restore, deleteAfter);
	}

	/**
	 * @param url
	 * @param restore
	 * @return a new {@link Serializer_Url}
	 * @throws IOException
	 */
	private static Serializer makeSerializer(final URL url, final boolean restore) throws IOException {
		return new Serializer_Url(url, restore);
	}

}
