/**
 * BeanPot Bean Container Project.
 * Copyright (C) 2009  Rubecula Software, LLC.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Module: Serializer_.java
 * Created on Jul 27, 2010
 * @version $Revision: 1.1 $
 */

package com.rubecula.beanpot.serialize;

import java.io.Closeable;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.ObjectStreamConstants;
import java.io.OutputStream;

import com.rubecula.beanpot.Serializer;

/**
 * @author Robin Hillyard
 * 
 */
public class Serializer_ implements Serializer {

	protected static class SerializationException extends RuntimeException {

		/**
		 * @param message
		 */
		public SerializationException(final String message) {
			super(message);
		}

		/**
		 * @param message
		 * @param cause
		 */
		public SerializationException(final String message, final Throwable cause) {
			super(message, cause);
		}

		/**
			 * 
			 */
		private static final long serialVersionUID = 8926614973612644994L;

	}

	/**
	 * @param objectStream
	 *            XXX
	 * @throws IOException
	 * 
	 */
	protected Serializer_(final ObjectStreamConstants objectStream) throws IOException {
		super();
		this._objectStream = objectStream;
		if (objectStream instanceof ObjectInputStream) {
			this._available = Integer.valueOf(-1);
			setAvailable();
			final int available = getAvailable();
			if (available <= 0)
				throw new SerializationException("empty object stream"); //$NON-NLS-1$
		}
	}

	/**
	 * @see com.rubecula.beanpot.Serializer#available()
	 */
	public int available() throws IOException {
		return getAvailable();
	}

	/**
	 * @see com.rubecula.beanpot.Serializer#close()
	 */
	public void close() throws IOException {
		if (this._objectStream instanceof ObjectInputStream) {
			setAvailable();
			if (available() > 0)
				throw new SerializationException("close(): stream has more input available"); //$NON-NLS-1$
		}
		if (this._objectStream instanceof Closeable) {
			((Closeable) this._objectStream).close();
			this._objectStream = null;
		} else
			throw new SerializationException("close(): stream is not Closeable"); //$NON-NLS-1$
	}

	/**
	 * @see com.rubecula.beanpot.Serializer#flush()
	 */
	public void flush() throws IOException {
		if (this._objectStream instanceof OutputStream)
			((OutputStream) this._objectStream).flush();
		throw new SerializationException("flush(): no output stream"); //$NON-NLS-1$
	}

	/**
	 * @see com.rubecula.beanpot.Serializer#readObject()
	 */
	public final Object readObject() throws IOException, ClassNotFoundException {
		if (this._objectStream instanceof ObjectInputStream) {
			final Object result = ((ObjectInputStream) this._objectStream).readObject();
			setAvailable();
			return result;
		}
		throw new SerializationException("Serialize.readObject(): no input stream"); //$NON-NLS-1$
	}

	/**
	 * @see com.rubecula.beanpot.Serializer#writeObject(java.lang.Object)
	 */
	public final void writeObject(final Object obj) throws IOException {
		if (this._objectStream instanceof ObjectOutputStream)
			((ObjectOutputStream) this._objectStream).writeObject(obj);
		else
			throw new SerializationException("writeObject no output stream"); //$NON-NLS-1$
	}

	/**
	 * It is not strictly necessary to cache the available count, we could
	 * always look it up directly. However, this caching mechanism makes
	 * debugging slightly easier.
	 */
	private int getAvailable() {
		if (this._available != null)
			return this._available.intValue();
		throw new SerializationException("Serialize.available(): no input stream"); //$NON-NLS-1$
	}

	/**
	 * @throws IOException
	 */
	private void setAvailable() throws IOException {
		if (this._available != null)
			this._available = Integer.valueOf(((ObjectInputStream) this._objectStream).available());
	}

	private Integer _available;

	private ObjectStreamConstants _objectStream;

}