/**
 * BeanPot Bean Container Project.
 * Copyright (C) 2009  Rubecula Software, LLC.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Module: Serializer.java
 * Created on Jul 20, 2010
 * @version $Revision: $
 */

package com.rubecula.beanpot.serialize;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectStreamConstants;

import com.rubecula.beanpot.Serializer;

/**
 * Implementation of the {@link Serializer} interface where the data source/sink
 * is a file.
 * 
 * @author Robin Hillyard
 * 
 */
public final class Serializer_File extends Serializer_ {

	/**
	 * @param file
	 * @param restore
	 * @return
	 * @throws IOException
	 * @throws FileNotFoundException
	 */
	private static ObjectStreamConstants createSerializerStream(final File file, final boolean restore) throws IOException,
			FileNotFoundException {
		if (restore)
			return new SerializeInputStream(new FileInputStream(file));
		return new SerializeOutputStream(new FileOutputStream(file));
	}

	/**
	 * Construct a Serializer which writes to a {@link File}.
	 * 
	 * @param file
	 * @throws IOException
	 * @throws FileNotFoundException
	 */
	Serializer_File(final File file) throws FileNotFoundException, IOException {
		this(file, false, false);
	}

	/**
	 * @param file
	 * @param restore
	 *            true if we are reading from the result of a previous
	 *            serialization
	 * @param deleteAfter
	 *            XXX
	 * @throws IOException
	 * @throws FileNotFoundException
	 */
	Serializer_File(final File file, final boolean restore, final boolean deleteAfter) throws FileNotFoundException, IOException {
		super(createSerializerStream(file, restore));
		this._file = file;
		this._deleteAfter = deleteAfter;
	}

	/**
	 * Construct a Serializer which sends output to {@link File} specified by
	 * <code>filename</code>.
	 * 
	 * @param filename
	 *            XXX
	 * @throws IOException
	 * @throws FileNotFoundException
	 * 
	 */
	Serializer_File(final String filename) throws FileNotFoundException, IOException {
		this(new File(filename), false, false);
	}

	/**
	 * @param filename
	 *            XXX
	 * @param restore
	 *            true if we are reading from the result of a previous
	 *            serialization
	 * @param deleteAfter
	 *            XXX
	 * @throws IOException
	 * @throws FileNotFoundException
	 * 
	 */
	Serializer_File(final String filename, final boolean restore, final boolean deleteAfter) throws FileNotFoundException,
			IOException {
		this(new File(filename), restore, deleteAfter);
	}

	/**
	 * @see com.rubecula.beanpot.serialize.Serializer_#close()
	 */
	@Override
	public void close() throws IOException {
		super.close();
		if (this._deleteAfter)
			deleteFile();
	}

	/**
	 * 
	 */
	void deleteFile() {
		if (this._file != null) {
			if (this._file.exists()) {
				this._file.delete();
				// System.out.println(this._file.getAbsolutePath() +
				// " deleted");
			}
		} else
			throw new SerializationException("deleteFile no file to delete"); //$NON-NLS-1$
	}

	/**
	 * @see java.lang.Object#finalize()
	 */
	@Override
	protected void finalize() throws Throwable {
		close();
		super.finalize();
	}

	private final boolean _deleteAfter;

	private final File _file;

}
